__copyright__    = 'Copyright (C) 2020 Otsuka Kentaro'
__version__      = '0.0.1'
__license__      = 'MIT License'
__author__       = 'Otsuka Kentaro'
__author_email__ = 'otsuka.kenchan@gmail.com'
__url__          = 'https://github.com/otsuka-kentaro/tensorflow-modules'

__all__ = []



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="tensorflow-modules",
    version="0.0.3",
    install_requires=[
        "tensorflow==2.4.0",
    ],
    # entry_points={},
    author="OtsukaKentaro",
    author_email="otsuka.kenchan@gmail.com",
    description="tensorflow layers, models",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/otsuka-kentaro/tensorflow-modules",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.8',
)
